unit Unit1;
{$INCLUDE MPDELVER.INC}


interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, Grids, MPHexEditor, StdCtrls, ExtCtrls, inifiles;

type
  TForm1 = class(TForm)
    Panel1: TPanel;
    Button1: TButton;
    OpenDialog1: TOpenDialog;
    MPHexEditor1: TMPHexEditor;
    Button2: TButton;
    Button3: TButton;
    Button4: TButton;
    SaveDialog1: TSaveDialog;
    procedure Button1Click(Sender: TObject);
    procedure ODMarkByte(Sender: TObject; ACanvas: TCanvas; ACol,
      ARow: Integer; var AWideText: WideString; ARect: TRect;
      var ADefaultDraw: Boolean);
    procedure FormCreate(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure Button3Click(Sender: TObject);
    procedure Button4Click(Sender: TObject);
  private

  public
    { Public declarations }
  end;

  TRange = class
    private
      //all the byte in range will be put here
      f:set of Byte;
    public
      function IsInRange(x:byte):boolean;
      procedure AddRange(RangeStart,RangeEnd:byte);
      procedure ClearRange;
      function IsEmptyRange:boolean;
  end;

Const
  IniName='am.ini';   //INI File name

var
  Form1: TForm1;
  Range: TRange;

implementation
{$IFNDEF DELPHI6UP}
const
  clMoneyGreen = TColor($C0DCC0);
  clSkyBlue = TColor($F0CAA6);
  clCream = TColor($F0FBFF);
{$ENDIF}

{$R *.dfm}

{TRange Start}


function TRange.IsInRange(x:byte):boolean;
begin
  if x In f  then
    Result:=True
  else
    Result:=False;
end;

procedure TRange.AddRange(RangeStart,RangeEnd:byte);
var
  i:integer;
begin
  for i := RangeStart to RangeEnd do
    begin
      f:=f+[i];
    end;
end;

procedure TRange.ClearRange;
begin
  f:=[];
end;

function TRange.IsEmptyRange:boolean;
begin
  if f=[0] then
     Result:=True
  else
     Result:=False;
end;
{TRange End}


procedure TForm1.Button1Click(Sender: TObject);
begin
  // Open file
  with OpenDialog1 do
    if Execute then
      MPHexEditor1.LoadFromFile(FileName);
end;

procedure TForm1.Button2Click(Sender: TObject);
var
  i:integer;
begin
  // Look for prev ASCII is marked
  with MPHexEditor1 do
  for i:=GetCursorPos-1 downto 0 do
    if Range.IsInRange(Data[i])=TRUE then
      begin
        //Goto to byte we find
        Seek(i,soFromBeginning);
        SetFocus;
        exit;
      end;
end;

procedure TForm1.Button3Click(Sender: TObject);
var
  i:integer;
begin
  // Look for next ASCII is marked
  with MPHexEditor1 do
  for i:=GetCursorPos+1 to DataSize-1 do
    if Range.IsInRange(Data[i])=TRUE then
      begin
        //Goto to byte we find
        Seek(i,soFromBeginning);
        SetFocus;
        exit;
      end;
end;

procedure TForm1.Button4Click(Sender: TObject);
begin
  //Save the file if changes have been made
  with SaveDialog1 do
    if Execute then
      MPHexEditor1.SaveToFile(FileName);
end;

procedure TForm1.ODMarkByte(Sender: TObject; ACanvas: TCanvas;
  ACol, ARow: Integer; var AWideText: WideString; ARect: TRect;
  var ADefaultDraw: Boolean);
var
  LIntCurPos: Integer;
begin
  with MPHexEditor1, ACanvas do
  begin
    LIntCurPos := PositionAtCursor[ACol, ARow];
    // skip ruler cols/rows and positions beyond the files size
    if (ACol > 0) and (ARow > 0) and (LIntCurPos < DataSize) and (Range.IsInRange(Data[LIntCurPos])=TRUE) then
    begin
       //Mark the BYTE
       SetBKColor(Handle, ColorToRGB(clMaroon));
       Font.Color := clYellow;
    end;
  end;
end;

procedure TForm1.FormCreate(Sender: TObject);
var
  MyFile:TIniFile;
begin
  // make sure that MYGRID is not defined in mphexeditor.pas
  Assert(MPHexEditor1 is TCustomGrid);
  MPHexEditor1.OnDrawCell := ODMarkByte;
  MPHexEditor1.Colors.EvenColumn :=MPHexEditor1.Colors.OddColumn;

  Range:=TRange.Create;
  Range.ClearRange;

  MyFile:=TInifile.Create(ExtractFilePath(paramstr(0))+IniName);
  if FileExists(ExtractFilePath(paramstr(0))+IniName)=FALSE then       //INI File doesnot exist
     begin
       MyFile.WriteInteger('AsciiMarked','Range1Start',0);
       MyFile.WriteInteger('Ascii Maker','Range1End',$09);
       MyFile.WriteInteger('Ascii Maker','Range2Start',$B);
       MyFile.WriteInteger('Ascii Maker','Range2End',$C);
       MyFile.WriteInteger('Ascii Maker','Range3Start',$E);
       MyFile.WriteInteger('Ascii Maker','Range3End',$1F);
       MyFile.WriteInteger('Ascii Maker','Range4Start',$7F);
       MyFile.WriteInteger('Ascii Maker','Range4End',$FF);
       MyFile.WriteInteger('Ascii Maker','Range5Start',0);
       MyFile.WriteInteger('Ascii Maker','Range5End',0);
       MyFile.WriteInteger('Ascii Maker','Range6Start',0);
       MyFile.WriteInteger('Ascii Maker','Range6End',0);
       MyFile.WriteInteger('Ascii Maker','Range7Start',0);
       MyFile.WriteInteger('Ascii Maker','Range7End',0);
       MyFile.WriteInteger('Ascii Maker','Range8Start',0);
       MyFile.WriteInteger('Ascii Maker','Range8End',0);
       MyFile.WriteInteger('Ascii Maker','Range9Start',0);
       MyFile.WriteInteger('Ascii Maker','Range9End',0);
       MyFile.WriteInteger('Ascii Maker','Range10Start',0);
       MyFile.WriteInteger('Ascii Maker','Range10End',0);
     end;

  Range.AddRange(
            MyFile.ReadInteger('Ascii Maker','Range1Start',0),
            MyFile.ReadInteger('Ascii Maker','Range1End',0));
  Range.AddRange(
            MyFile.ReadInteger('Ascii Maker','Range2Start',0),
            MyFile.ReadInteger('Ascii Maker','Range2End',0));
  Range.AddRange(
            MyFile.ReadInteger('Ascii Maker','Range3Start',0),
            MyFile.ReadInteger('Ascii Maker','Range3End',0));
  Range.AddRange(
            MyFile.ReadInteger('Ascii Maker','Range4Start',0),
            MyFile.ReadInteger('Ascii Maker','Range4End',0));
  Range.AddRange(
            MyFile.ReadInteger('Ascii Maker','Range5Start',0),
            MyFile.ReadInteger('Ascii Maker','Range5End',0));
  Range.AddRange(
            MyFile.ReadInteger('Ascii Maker','Range6Start',0),
            MyFile.ReadInteger('Ascii Maker','Range6End',0));
  Range.AddRange(
            MyFile.ReadInteger('Ascii Maker','Range7Start',0),
            MyFile.ReadInteger('Ascii Maker','Range72End',0));
  Range.AddRange(
            MyFile.ReadInteger('Ascii Maker','Range8Start',0),
            MyFile.ReadInteger('Ascii Maker','Range8End',0));
  Range.AddRange(
            MyFile.ReadInteger('Ascii Maker','Range9Start',0),
            MyFile.ReadInteger('Ascii Maker','Range9End',0));
  Range.AddRange(
            MyFile.ReadInteger('Ascii Maker','Range10Start',0),
            MyFile.ReadInteger('Ascii Maker','Range10End',0));

  if Range.IsEmptyRange then
      begin
        ShowMessage('INI Error. Please delete '+IniName+' file');
      end;
  MyFile.Destroy;
end;

end.
